@@ -49,7 +49,7 @@ devnull = open(os.devnull, "wb")  # to redirect unwanted subprocess output
 allowed_ssh_connections = {}
 concurrent_git_connection_limit = threading.Semaphore(5)
 
-_prebuilt_cctbx_base = "2024.9"
+_prebuilt_cctbx_base = "2025.5"
 
 
 def make_executable(filepath):
@@ -841,7 +841,7 @@ def update_sources(options):
         repositories = {
             source.split("/")[1]: {
                 "base-repository": source,
-                "branch-local": "dials-3.22",
+                "branch-local": "dials-3.25",
             }
             for source, branch in (
                 ("dials/annlib_adaptbx", "master"),
@@ -851,24 +851,24 @@ def update_sources(options):
                 ("dials/ccp4io", "master"),
                 ("dials/cctbx_project", "master"),
                 ("dials/dials", "main"),
-                ("dials/dxtbx", "main"),
+                ("cctbx/dxtbx", "main"),
                 ("dials/gui_resources", "master"),
                 ("xia2/xia2", "main"),
             )
         }
         repositories["cctbx_project"] = {
             "base-repository": "dials/cctbx_project",
-            "branch-local": "dials-3.22",
+            "branch-local": "dials-3.25",
         }
     else:
         # Only what we need for CMake
         repositories = {
             source.split("/")[1]: {
                 "base-repository": source,
-                "branch-local": "dials-3.22",
+                "branch-local": "dials-3.25",
             }
             for source, branch in (
-                ("dials/dxtbx", "main"),
+                ("cctbx/dxtbx", "main"),
                 ("dials/dials", "main"),
                 ("xia2/xia2", "main"),
             )
@@ -1037,7 +1037,8 @@ def refresh_build_cmake():
     )
 
 
-def configure_build_cmake():
+def configure_build_cmake(extra_args):
+    # type: (list[str] | None) -> None
     cmake_exe = _get_cmake_exe()
     python_exe = _get_base_python()
 
@@ -1100,6 +1101,11 @@ conda activate {dist_root}/conda_base
 cmake_minimum_required(VERSION 3.20 FATAL_ERROR)
 project(dials)
 
+if (CMAKE_UNITY_BUILD AND MSVC)
+    # Windows can fail in this scenario because too many objects
+    add_compile_options(/bigobj)
+endif()
+
 add_subdirectory(dxtbx)
 add_subdirectory(dials)
 """
@@ -1108,9 +1114,10 @@ add_subdirectory(dials)
     # run_indirect runs inside the build folder with an activated environment
     conda_base_root = os.path.join(os.path.abspath("."), "conda_base")
     assert os.path.isdir(conda_base_root)
-    extra_args = []
+    extra_args = extra_args or []
     if os.name == "nt":
         extra_args.append("-DPython_ROOT_DIR=" + conda_base_root)
+    sys.stdout.flush()
     run_indirect_command(
         cmake_exe,
         [
@@ -1259,17 +1266,17 @@ def run():
     )
     parser.add_argument(
         "--config-flags",
-        help="""Pass flags to the configuration step. Flags should
+        help="""Pass flags to the configuration step (CMake or libtbx). Flags should
 be passed separately with quotes to avoid confusion (e.g
---config_flags="--build=debug" --config_flags="--another_flag")""",
+--config-flags="--build=debug" --config-flags="--another_flag")""",
         action="append",
         default=[],
     )
     parser.add_argument(
         "--python",
         help="Install this minor version of Python (default: %(default)s)",
-        default="3.11",
-        choices=("3.9", "3.10", "3.11", "3.12"),
+        default="3.13",
+        choices=("3.10", "3.11", "3.12", "3.13"),
     )
     parser.add_argument(
         "--branch",
@@ -1326,7 +1333,7 @@ be passed separately with quotes to avoid confusion (e.g
     if "build" in options.actions:
         if options.cmake:
             refresh_build_cmake()
-            configure_build_cmake()
+            configure_build_cmake(options.config_flags)
             make_build_cmake()
         else:
             configure_build(options.config_flags)
