@@ -11,11 +11,6 @@ from pathlib import Path
 import libtbx
 import libtbx.pkg_utils
 
-try:
-    import pkg_resources
-except ModuleNotFoundError:
-    pkg_resources = None
-
 # So that we can import DIALS within this script, work out where the
 # sources are and make them importable
 _src_path_root = str(Path(libtbx.env.dist_path("dials")).joinpath("src"))
@@ -75,6 +70,25 @@ dials.precommitbx.nagger.nag()
 libtbx.pkg_utils.define_entry_points({})
 
 
+def _find_site_packages_with_metadata(package_name: str, build_path: Path):
+    """
+    Find the site-packages directory containing the package metadata.
+    Returns the site-packages directory if metadata is found, None otherwise.
+    """
+    # Look for Python site-packages directories in the build path
+    for python_dir in build_path.glob("lib/python*"):
+        site_packages = python_dir / "site-packages"
+        if site_packages.exists():
+            # Look for both .dist-info and .egg-info directories
+            for pattern in [f"{package_name}*.dist-info", f"{package_name}*.egg-info"]:
+                for metadata_dir in site_packages.glob(pattern):
+                    if metadata_dir.exists():
+                        # Return site-packages only if we actually found metadata
+                        return site_packages
+            # If no metadata found in this site-packages, continue searching
+    return None
+
+
 def _install_setup_readonly_fallback(package_name: str):
     """
     Partially install package in the libtbx build folder.
@@ -106,22 +120,19 @@ def _install_setup_readonly_fallback(package_name: str):
     # Get the actual environment being configured (NOT libtbx.env)
     env = _get_real_env_hack_hack_hack()
 
-    # Update the libtbx environment pythonpaths to point to the source
-    # location which now has an .egg-info folder; this will mean that
-    # the PYTHONPATH is written into the libtbx dispatchers
-    rel_path = libtbx.env.as_relocatable_path(import_path)
-    if rel_path not in env.pythonpath:
-        env.pythonpath.insert(0, rel_path)
+    # As of PEP 660, the package metadata (dist-info) goes in the install dir,
+    # not the source dir. Add this location to the python path.
+    metadata_dir = _find_site_packages_with_metadata(package_name, Path(build_path))
+    if metadata_dir and metadata_dir not in sys.path:
+        metadata_rel = libtbx.env.as_relocatable_path(str(metadata_dir))
+        if metadata_rel not in env.pythonpath:
+            env.pythonpath.insert(0, metadata_rel)
 
-    # Update the sys.path so that we can find the .egg-info in this process
+    # Update the sys.path so we can find the package in this process
     # if we do a full reconstruction of the working set
     if import_path not in sys.path:
         sys.path.insert(0, import_path)
 
-    # ...and add to the existing pkg_resources working_set
-    if pkg_resources:
-        pkg_resources.working_set.add_entry(import_path)
-
     # Add the src/ folder as an extra command_line_locations for dispatchers
     module = env.module_dict[package_name]
     if f"src/{package_name}" not in module.extra_command_line_locations:
