@@ -1,6 +1,6 @@
 from __future__ import annotations
 
 from dials.algorithms.background.glm.algorithm import BackgroundAlgorithm
-from dials_algorithms_background_glm_ext import *  # noqa: F403; lgtm
+from dials_algorithms_background_glm_ext import *  # noqa: F403
 
 __all__ = ("BackgroundAlgorithm", "Creator", "RobustPoissonMean")  # noqa: F405
