@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from dials.algorithms.background.gmodel.algorithm import BackgroundAlgorithm
-from dials_algorithms_background_gmodel_ext import *  # noqa: F403; lgtm
+from dials_algorithms_background_gmodel_ext import *  # noqa: F403
 
 __all__ = (  # noqa: F405
     "BackgroundAlgorithm",
