@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from dials_algorithms_filter_ext import *  # noqa: F403; lgtm
+from dials_algorithms_filter_ext import *  # noqa: F403
 
 __all__ = (  # noqa: F405
     "by_bbox_volume",
