@@ -65,12 +65,9 @@ def plot_displacements(reflections, predictions, experiments):
 
 def e_refine(params, experiments, reflections, graph_verbose=False):
     # Stills-specific parameters we always want
-    assert (
-        params.refinement.reflections.outlier.algorithm
-        in (
-            None,
-            "null",
-        )
+    assert params.refinement.reflections.outlier.algorithm in (
+        None,
+        "null",
     ), (
         "Cannot index, set refinement.reflections.outlier.algorithm=null"
     )  # we do our own outlier rejection
@@ -591,9 +588,9 @@ class StillsIndexer(Indexer):
                         graph_verbose=False,
                     )
                     crystal_model = nv()
-                    assert (
-                        len(crystal_model) == 1
-                    ), "$$$ stills_indexer::choose_best_orientation_matrix, Only one crystal at this stage"
+                    assert len(crystal_model) == 1, (
+                        "$$$ stills_indexer::choose_best_orientation_matrix, Only one crystal at this stage"
+                    )
                     crystal_model = crystal_model[0]
 
                     # Drop candidates that after refinement can no longer be converted to the known target space group
