@@ -1,5 +1,5 @@
 from __future__ import annotations
 
-from dials_algorithms_integration_fit_ext import *  # noqa: F403; lgtm
+from dials_algorithms_integration_fit_ext import *  # noqa: F403
 
 __all__ = ("ProfileFitter", "ProfileFitterDouble", "ProfileFitterFloat")  # noqa: F405
