@@ -332,12 +332,12 @@ class IntegrationJob:
             params = phil_scope.extract()
 
         assert len(reflections) > 0, "Zero reflections given"
-        assert (
-            params.integration.block.max_memory_usage > 0.0
-        ), "Max memory % must be > 0"
-        assert (
-            params.integration.block.max_memory_usage <= 1.0
-        ), "Max memory % must be < 1"
+        assert params.integration.block.max_memory_usage > 0.0, (
+            "Max memory % must be > 0"
+        )
+        assert params.integration.block.max_memory_usage <= 1.0, (
+            "Max memory % must be < 1"
+        )
         self.index = index
         self.job = job
         self.experiments = experiments
@@ -782,12 +782,12 @@ class ReferenceCalculatorJob:
             params = phil_scope.extract()
 
         assert len(reflections) > 0, "Zero reflections given"
-        assert (
-            params.integration.block.max_memory_usage > 0.0
-        ), "Max memory % must be > 0"
-        assert (
-            params.integration.block.max_memory_usage <= 1.0
-        ), "Max memory % must be < 1"
+        assert params.integration.block.max_memory_usage > 0.0, (
+            "Max memory % must be > 0"
+        )
+        assert params.integration.block.max_memory_usage <= 1.0, (
+            "Max memory % must be < 1"
+        )
         self.index = index
         self.job = job
         self.experiments = experiments
