@@ -165,13 +165,7 @@ def integrate_coset(self, experiments, indexed):
 
     for crystal_model in experiments_local.crystals():
         if hasattr(crystal_model, "get_domain_size_ang"):
-            log_str += (
-                ". Final ML model: domain size angstroms: %f, half mosaicity degrees: %f"
-                % (
-                    crystal_model.get_domain_size_ang(),
-                    crystal_model.get_half_mosaicity_deg(),
-                )
-            )
+            log_str += f". Final ML model: domain size angstroms: {crystal_model.get_domain_size_ang():f}, half mosaicity degrees: {crystal_model.get_half_mosaicity_deg():f}"
 
     logger.info(log_str)
     logger.info("")
