@@ -2,8 +2,8 @@ from __future__ import annotations
 
 from math import pi, sqrt
 
-from dials.array_family import flex  # noqa: F401;
-from dials_algorithms_profile_model_ellipsoid_ext import *  # noqa: F401, F403;
+from dials.array_family import flex  # noqa: F401
+from dials_algorithms_profile_model_ellipsoid_ext import *  # noqa: F401, F403
 
 
 def mosaicity_from_eigen_decomposition(eigen_values):
