@@ -11,6 +11,7 @@
 #ifndef DIALS_ALGORITHMS_PROFILE_MODEL_GAUSSIAN_RS_TRANSFORM_H
 #define DIALS_ALGORITHMS_PROFILE_MODEL_GAUSSIAN_RS_TRANSFORM_H
 
+#include <memory>
 #include <scitbx/vec2.h>
 #include <scitbx/vec3.h>
 #include <scitbx/array_family/tiny_types.h>
@@ -24,11 +25,8 @@
 #include <dials/algorithms/profile_model/gaussian_rs/transform/beam_vector_map.h>
 #include <dials/model/data/shoebox.h>
 
-namespace dials {
-  namespace algorithms {
-    namespace profile_model {
-      namespace gaussian_rs {
-  namespace transform {
+namespace dials { namespace algorithms { namespace profile_model {
+  namespace gaussian_rs { namespace transform {
 
     using dials::algorithms::polygon::simple_area;
     using dials::algorithms::polygon::clip::quad_with_convex_quad;
@@ -79,7 +77,7 @@ namespace dials {
        * @param n_sigma The number of standard deviations
        * @param grid_size The size of the reflection basis grid
        */
-      TransformSpec(const boost::shared_ptr<BeamBase> beam,
+      TransformSpec(const std::shared_ptr<BeamBase> beam,
                     const Detector &detector,
                     const Goniometer &gonio,
                     const Scan &scan,
@@ -109,7 +107,7 @@ namespace dials {
       }
 
       /** @returns the beam */
-      const boost::shared_ptr<BeamBase> beam() const {
+      const std::shared_ptr<BeamBase> beam() const {
         return beam_;
       }
 
@@ -164,7 +162,7 @@ namespace dials {
       }
 
     private:
-      boost::shared_ptr<BeamBase> beam_;
+      std::shared_ptr<BeamBase> beam_;
       Detector detector_;
       Goniometer goniometer_;
       Scan scan_;
