@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import logging
 from collections import namedtuple
 
 from scitbx import matrix, sparse
@@ -17,6 +18,8 @@ for scan-static reflection prediction for rotation data, where the predicted
 centroid is expressed as X, Y, phi. Other versions of the class are defined
 elsewhere."""
 
+logger = logging.getLogger(__name__)
+
 ParamSet = namedtuple(
     "ParamSet",
     ["beam_param", "xl_ori_param", "xl_uc_param", "det_param", "gonio_param"],
@@ -248,7 +251,12 @@ class PredictionParameterisation:
             elif set_fix:
                 current_fixes = model.get_fixed()
                 free_indices = [i for i, e in enumerate(current_fixes) if not e]
-                assert len(free_indices) == model.num_free()
+                if len(free_indices) != model.num_free():
+                    logger.warning(
+                        "Unable to fix parameters for parameterisation with prefix %s",
+                        model.model_identifier,
+                    )
+                    continue
                 for i, fix in zip(free_indices, tmp):
                     if fix:
                         current_fixes[i] = True
@@ -761,7 +769,7 @@ class XYPhiPredictionParameterisation(PredictionParameterisation):
             print("where r =", self._r[imin])
             print("e =", self._axis[imin])
             print("s0 =", self._s0[imin])
-            print("this reflection forms angle with the equatorial plane " "normal:")
+            print("this reflection forms angle with the equatorial plane normal:")
             vecn = (
                 matrix.col(self._s0[imin])
                 .cross(matrix.col(self._axis[imin]))
