@@ -451,9 +451,9 @@ class ScanVaryingPredictionParameterisation(XYPhiPredictionParameterisation):
                 frames = reflections["block_centre"].select(subsel)
 
                 # can only be false if original block assignment has gone wrong
-                assert frames.all_eq(
-                    frames[0]
-                ), "Failing: a block contains reflections that shouldn't be there"
+                assert frames.all_eq(frames[0]), (
+                    "Failing: a block contains reflections that shouldn't be there"
+                )
                 frame = int(math.floor(frames[0]))
 
                 # model states at current frame
