@@ -672,8 +672,11 @@ class ReflectionManager:
         # exclude reflections with overloads, as these have worse centroids
         sel2 = ~obs_data.get_flags(obs_data.flags.overloaded)
 
+        # exclude reflections marked as not suitable
+        sel3 = ~obs_data.get_flags(obs_data.flags.not_suitable_for_refinement)
+
         # combine selections
-        sel = sel1 & sel2
+        sel = sel1 & sel2 & sel3
         inc = flex.size_t_range(len(obs_data)).select(sel)
         obs_data = obs_data.select(sel)
 
@@ -857,7 +860,7 @@ class ReflectionManager:
         row_data = five_number_summary(w_y)
         rows.append(["Y weights"] + [f"{e:.4g}" for e in row_data])
         row_data = five_number_summary(w_phi)
-        rows.append(["Phi weights"] + [f"{e * DEG2RAD ** 2:.4g}" for e in row_data])
+        rows.append(["Phi weights"] + [f"{e * DEG2RAD**2:.4g}" for e in row_data])
 
         logger.info(msg)
         logger.info(dials.util.tabulate(rows, header, numalign="right") + "\n")
@@ -913,8 +916,11 @@ class StillsReflectionManager(ReflectionManager):
         # exclude reflections with overloads, as these have worse centroids
         sel2 = ~obs_data.get_flags(obs_data.flags.overloaded)
 
+        # exclude reflections marked as not suitable
+        sel3 = ~obs_data.get_flags(obs_data.flags.not_suitable_for_refinement)
+
         # combine selections
-        sel = sel1 & sel2
+        sel = sel1 & sel2 & sel3
         inc = flex.size_t_range(len(obs_data)).select(sel)
 
         return inc
@@ -954,9 +960,7 @@ class StillsReflectionManager(ReflectionManager):
         row_data = five_number_summary(w_y)
         rows.append(["Y weights"] + [f"{e:.4g}" for e in row_data])
         row_data = five_number_summary(w_delpsi)
-        rows.append(
-            ["DeltaPsi weights"] + [f"{e * DEG2RAD ** 2:.4g}" for e in row_data]
-        )
+        rows.append(["DeltaPsi weights"] + [f"{e * DEG2RAD**2:.4g}" for e in row_data])
 
         msg = (
             f"\nSummary statistics for {nref} observations" + " matched to predictions:"
@@ -1074,8 +1078,11 @@ class LaueReflectionManager(ReflectionManager):
         # exclude reflections with overloads, as these have worse centroids
         sel2 = ~obs_data.get_flags(obs_data.flags.overloaded)
 
+        # exclude reflections marked as not suitable
+        sel3 = ~obs_data.get_flags(obs_data.flags.not_suitable_for_refinement)
+
         # combine selections
-        sel = sel1 & sel2
+        sel = sel1 & sel2 & sel3
         inc = flex.size_t_range(len(obs_data)).select(sel)
 
         return inc
