@@ -19,6 +19,7 @@ namespace dials_scaling { namespace boost_python {
   void export_create_sph_harm_lookup_table();
   void export_gaussian_smoother_first_fixed();
   void export_limit_outlier_weights();
+  void export_split_unmerged();
 
   BOOST_PYTHON_MODULE(dials_scaling_ext) {
     export_elementwise_square();
@@ -35,6 +36,7 @@ namespace dials_scaling { namespace boost_python {
     export_create_sph_harm_lookup_table();
     export_gaussian_smoother_first_fixed();
     export_limit_outlier_weights();
+    export_split_unmerged();
   }
 
 }}  // namespace dials_scaling::boost_python
