@@ -94,9 +94,7 @@ class ScaleComponentBase:
 
     @parameters.setter
     def parameters(self, new_parameters):
-        assert len(new_parameters) == len(
-            self._parameters
-        ), f"""
+        assert len(new_parameters) == len(self._parameters), f"""
 attempting to set a new set of parameters of different length than previous
 assignment: was {len(self._parameters)}, attempting {len(new_parameters)}"""
         self._parameters = new_parameters
@@ -191,9 +189,7 @@ class SingleScaleFactor(ScaleComponentBase):
 
     def __init__(self, initial_values, parameter_esds=None):
         """Set the initial parameter values, parameter esds and n_params."""
-        assert (
-            len(initial_values) == 1
-        ), """
+        assert len(initial_values) == 1, """
 This model component can only hold a single parameter."""
         super().__init__(initial_values, parameter_esds)
 
