@@ -7,11 +7,10 @@ methods to define how these are composed into one model.
 
 from __future__ import annotations
 
+import importlib.metadata
 import logging
 import math
 
-import pkg_resources
-
 from libtbx import Auto, phil
 
 from dials.algorithms.scaling.error_model.error_model import BasicErrorModel
@@ -1511,11 +1510,12 @@ def calc_n_param_from_bins(value_min, value_max, n_bins):
 
 model_phil_scope = phil.parse("")
 _dxtbx_scaling_models = {
-    ep.name: ep for ep in pkg_resources.iter_entry_points("dxtbx.scaling_model_ext")
+    ep.name: ep
+    for ep in importlib.metadata.entry_points(group="dxtbx.scaling_model_ext")
 }
-assert (
-    _dxtbx_scaling_models
-), "No models registered with dxtbx.scaling_model_ext entry point"
+assert _dxtbx_scaling_models, (
+    "No models registered with dxtbx.scaling_model_ext entry point"
+)
 model_phil_scope.adopt_scope(
     phil.parse(
         "model ="
