@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from dials_algorithms_simulation_ext import *  # noqa: F403; lgtm
+from dials_algorithms_simulation_ext import *  # noqa: F403
 
 __all__ = (  # noqa: F405
     "integrate_reciprocal_space_gaussian",
