@@ -24,6 +24,7 @@ namespace dials { namespace algorithms { namespace boost_python {
   void export_rotation_angles();
   void export_ray_predictor();
   void export_scan_varying_ray_predictor();
+  void export_laue_ray_predictor();
   void export_stills_ray_predictor();
   void export_ray_intersection();
   void export_reflection_predictor();
@@ -40,6 +41,7 @@ namespace dials { namespace algorithms { namespace boost_python {
     export_ray_predictor();
     export_scan_varying_ray_predictor();
     export_stills_ray_predictor();
+    export_laue_ray_predictor();
     export_ray_intersection();
     export_reflection_predictor();
     export_pixel_labeller();
