@@ -164,9 +164,9 @@ class CosymAnalysis(symmetry_base, Subject):
         self.seed_dataset = seed_dataset
         if self.seed_dataset:
             self.seed_dataset = int(self.seed_dataset)
-            assert (
-                0 <= seed_dataset < len(intensities)
-            ), "cosym_analysis: seed_dataset parameter must be an integer that can be used to index the intensities list"
+            assert 0 <= seed_dataset < len(intensities), (
+                "cosym_analysis: seed_dataset parameter must be an integer that can be used to index the intensities list"
+            )
 
         max_id = len(intensities) - 1
         super().__init__(
@@ -420,11 +420,15 @@ class CosymAnalysis(symmetry_base, Subject):
             self.target.dim, NN * n_sym_ops
         ).transpose()
 
-    def _principal_component_analysis(self):
+    def _principal_component_analysis(self, cluster=False):
         # Perform PCA
         from sklearn.decomposition import PCA
 
-        pca = PCA().fit(self.coords)
+        if cluster:
+            logger.info(f"Dimensions used for clustering PCA: {self.target.dim}")
+            pca = PCA(n_components=self.target.dim).fit(self.coords)
+        else:
+            pca = PCA().fit(self.coords)
         logger.info("Principal component analysis:")
         logger.info(
             "Explained variance: "
@@ -436,9 +440,10 @@ class CosymAnalysis(symmetry_base, Subject):
         )
         self.explained_variance = pca.explained_variance_
         self.explained_variance_ratio = pca.explained_variance_ratio_
-        if self.target.dim > 3:
+        if self.target.dim > 3 and not cluster:
             pca.n_components = 3
         self.coords_reduced = pca.fit_transform(self.coords)
+        self.pca_components = pca.components_
 
     @Subject.notify_event(event="analysed_symmetry")
     def _analyse_symmetry(self):
