@@ -26,8 +26,6 @@ import math
 import sys
 import warnings
 
-from orderedset import OrderedSet
-
 from dxtbx.model.experiment_list import Experiment, ExperimentList
 from libtbx.phil import parse
 
@@ -512,11 +510,11 @@ def run_integration(params, experiments, reference=None):
         force_static=params.prediction.force_static,
         padding=params.prediction.padding,
     )
-    isets = OrderedSet(e.imageset for e in experiments)
+    isets = {e.imageset: i for i, e in enumerate(experiments)}
     predicted["imageset_id"] = flex.int(predicted.size(), 0)
     if len(isets) > 1:
         for e in experiments:
-            iset_id = isets.index(e.imageset)
+            iset_id = isets[e.imageset]
             for id_ in predicted.experiment_identifiers().keys():
                 identifier = predicted.experiment_identifiers()[id_]
                 if identifier == e.identifier:
