@@ -40,6 +40,17 @@ class Script:
             self.parser.print_help()
             return
 
+        # list columns
+        cols = "\n showing columns:"
+        ikey = 0
+        for key in table[0].keys():
+            cols = cols + " " + key
+            ikey = ikey + 1
+            if ikey == 5:
+                cols = cols + "\n                 "
+                ikey = 0
+        print(cols + "\n")
+
         extract_n_show(table[0])
 
 
