@@ -122,9 +122,9 @@ projection {
     .type = bool
     .help = "Plot the diffraction image with the computed beam center."
 
-    verbose = True
+    bar = True
     .type = bool
-    .help = "Print the beam position to the output."
+    .help = "Print progress bar."
 
     exclude_pixel_range_x = None
     .type = ints
@@ -795,7 +795,7 @@ def run(args=None):
                         (int(set_index), int(image_index), float(x), float(y))
                     )
 
-                    if params.projection.verbose:
+                    if params.projection.bar:
                         print_progress(
                             image_index=image_run_index,
                             n_images=num_selected_images,
@@ -804,6 +804,11 @@ def run(args=None):
                             x=x,
                             y=y,
                         )
+                    else:
+                        out_str = f"set {int(set_index):04d}, "
+                        out_str += f"image {int(image_index):04d}: "
+                        out_str += f"{x:.2f} {y:.2f}"
+                        print(out_str)
 
             # Compute beam position for the average image
             else:
@@ -822,7 +827,7 @@ def run(args=None):
                         else:
                             avg_image = avg_image + image
 
-                        if params.projection.verbose:
+                        if params.projection.bar:
                             print_progress(
                                 image_index=image_run_index,
                                 n_images=num_selected_images,
@@ -850,7 +855,7 @@ def run(args=None):
             with open(params.output.json, "w") as json_file:
                 json.dump(json_output, json_file, indent=4)
 
-            if params.projection.verbose:
+            if params.projection.bar:
                 print()
 
 
@@ -869,9 +874,9 @@ def print_progress(image_index, n_images, set_index, n_sets, x, y, bar_length=40
     set_bar_full = int(percent_sets * bar_length)
     set_bar = "=" * set_bar_full + " " * (bar_length - set_bar_full)
 
-    bar = f" Set:   [{set_bar}] {100*percent_sets:0.2f} % "
+    bar = f" Set:   [{set_bar}] {100 * percent_sets:0.2f} % "
     bar += f"{set_index:4d}/{n_sets:d}\n"
-    bar += f" Image: [{image_bar}] {100*percent_images:0.2f} % "
+    bar += f" Image: [{image_bar}] {100 * percent_images:0.2f} % "
     bar += f"{image_index:4d}/{n_images}\n"
 
     if abs(percent_sets - 1.0) < 1.0e-15 and abs(percent_images - 1.0) < 1.0e-15:
