@@ -4,7 +4,7 @@ import boost_adaptbx.boost.python
 
 ext = boost_adaptbx.boost.python.import_ext("dials_model_data_ext")
 
-from dials_model_data_ext import *  # noqa: F403; lgtm
+from dials_model_data_ext import *  # noqa: F403, E402
 
 __all__ = (  # noqa: F405
     "AdjacencyList",
