@@ -3,4 +3,4 @@ from __future__ import annotations
 from boost_adaptbx.boost import optional
 
 from dials.array_family import flex
-from dials_nexus_ext import *
+from dials_nexus_ext import *  # noqa: F403
