@@ -17,11 +17,6 @@ from dials.util.filter_reflections import (
     filter_reflection_table,
 )
 
-try:
-    from typing import Tuple  # noqa: F401
-except ImportError:
-    pass
-
 logger = logging.getLogger(__name__)
 
 
@@ -51,7 +46,7 @@ def _export_experiment(
     integrated_data: flex.reflection_table,
     experiment: dxtbx.model.Experiment,
     params: libtbx.phil.scope_extract,
-    var_model: Tuple = (1, 0),
+    var_model: tuple = (1, 0),
 ):
     """Export a single experiment to an XDS_ASCII.HKL format file.
 
@@ -153,7 +148,11 @@ def _export_experiment(
     slow = panel.get_slow_axis()
     Rd = align_reference_frame(fast, (1, 0, 0), slow, (0, 1, 0))
     print("Coordinate change:")
-    print("%5.2f %5.2f %5.2f\n%5.2f %5.2f %5.2f\n%5.2f %5.2f %5.2f\n" % Rd.elems)
+    print(
+        "{:5.2f} {:5.2f} {:5.2f}\n{:5.2f} {:5.2f} {:5.2f}\n{:5.2f} {:5.2f} {:5.2f}\n".format(
+            *Rd.elems
+        )
+    )
 
     fast = Rd * fast
     slow = Rd * slow
@@ -187,7 +186,7 @@ def _export_experiment(
                 "!FORMAT=XDS_ASCII    MERGE=FALSE    FRIEDEL'S_LAW=TRUE",
                 "!Generated by dials.export",
                 "!DATA_RANGE= %d %d" % image_range,
-                "!ROTATION_AXIS= %9.6f %9.6f %9.6f" % axis.elems,
+                "!ROTATION_AXIS= {:9.6f} {:9.6f} {:9.6f}".format(*axis.elems),
                 "!OSCILLATION_RANGE= %f" % phi_range,
                 "!STARTING_ANGLE= %f" % phi_start,
                 "!STARTING_FRAME= %d" % image_range[0],
@@ -198,13 +197,17 @@ def _export_experiment(
                 f"!UNIT_CELL_B-AXIS= {axis_fmt % real_space_ABC[3:6]}",
                 f"!UNIT_CELL_C-AXIS= {axis_fmt % real_space_ABC[6:9]}",
                 f"!X-RAY_WAVELENGTH= {experiment.beam.get_wavelength():f}",
-                "!INCIDENT_BEAM_DIRECTION= %f %f %f" % beam.elems,
+                "!INCIDENT_BEAM_DIRECTION= {:f} {:f} {:f}".format(*beam.elems),
                 "!NX= %d NY= %d QX= %f QY= %f" % (nx, ny, qx, qy),
                 f"!ORGX= {orgx:9.2f} ORGY= {orgy:9.2f}",
                 f"!DETECTOR_DISTANCE= {distance:8.3f}",
-                "!DIRECTION_OF_DETECTOR_X-AXIS= %9.5f %9.5f %9.5f" % fast.elems,
-                "!DIRECTION_OF_DETECTOR_Y-AXIS= %9.5f %9.5f %9.5f" % slow.elems,
-                "!VARIANCE_MODEL= %7.3e %7.3e" % var_model,
+                "!DIRECTION_OF_DETECTOR_X-AXIS= {:9.5f} {:9.5f} {:9.5f}".format(
+                    *fast.elems
+                ),
+                "!DIRECTION_OF_DETECTOR_Y-AXIS= {:9.5f} {:9.5f} {:9.5f}".format(
+                    *slow.elems
+                ),
+                "!VARIANCE_MODEL= {:7.3e} {:7.3e}".format(*var_model),
                 "!NUMBER_OF_ITEMS_IN_EACH_DATA_RECORD=12",
                 "!ITEM_H=1",
                 "!ITEM_K=2",
