@@ -115,7 +115,8 @@ class XrayFrame(XFBaseClass):
         self._ring_frame = None
         self._uc_frame = None
         self._score_frame = None
-        self._plugins_frame = {key: None for key in self.plugins}
+        self._line_frame = None
+        self._plugins_frame = dict.fromkeys(self.plugins)
         self.zoom_frame = None
         self.plot_frame = None
 
@@ -143,6 +144,7 @@ class XrayFrame(XFBaseClass):
         self.Bind(wx.EVT_UPDATE_UI, self.OnUpdateUIRing, id=self._id_ring)
         self.Bind(wx.EVT_UPDATE_UI, self.OnUpdateUIUC, id=self._id_uc)
         self.Bind(wx.EVT_UPDATE_UI, self.OnUpdateUIScore, id=self._id_score)
+        self.Bind(wx.EVT_UPDATE_UI, self.OnUpdateUILine, id=self._id_line)
         for p in self.plugins:
             self.Bind(
                 wx.EVT_UPDATE_UI,
@@ -202,10 +204,7 @@ class XrayFrame(XFBaseClass):
                 lon, lat
             )
 
-            posn_str = "Picture:  fast={:.3f} / slow={:.3f} pixels.".format(
-                fast_picture + 0.5,
-                slow_picture + 0.5,
-            )
+            posn_str = f"Picture:  fast={fast_picture + 0.5:.3f} / slow={slow_picture + 0.5:.3f} pixels."
             coords = self.pyslip.tiles.get_flex_pixel_coordinates(lon, lat)
             if len(coords) >= 2:
                 if len(coords) == 3:
@@ -311,6 +310,11 @@ class XrayFrame(XFBaseClass):
         item = self._actions_menu.Append(self._id_score, " ")
         self.Bind(wx.EVT_MENU, self.OnScore, source=item)
 
+        # XXX Placement
+        self._id_line = wx.NewId()
+        item = self._actions_menu.Append(self._id_line, " ")
+        self.Bind(wx.EVT_MENU, self.OnLine, source=item)
+
         self._id_plugins = {}
         for p in self.plugins:
             self._id_plugins[p] = wx.NewId()
@@ -364,7 +368,7 @@ class XrayFrame(XFBaseClass):
         # FIXME assumes all detector elements use the same millimeter-to-pixel convention
         try:
             # determine if the beam intersects one of the panels
-            panel_id, (x_mm, y_mm) = detector.get_ray_intersection(beam.get_s0())
+            panel_id, (x_mm, y_mm) = detector.get_ray_intersection(beam.get_unit_s0())
         except RuntimeError as e:
             if not ("DXTBX_ASSERT(" in str(e) and ") failure" in str(e)):
                 # unknown exception from dxtbx
@@ -374,12 +378,12 @@ class XrayFrame(XFBaseClass):
             lowest_res = 0
             for p_id, panel in enumerate(detector):
                 w, h = panel.get_image_size()
-                res = panel.get_resolution_at_pixel(beam.get_s0(), (w // 2, h // 2))
+                res = panel.get_resolution_at_pixel(beam, (w // 2, h // 2))
                 if res > lowest_res:
                     panel_id = p_id
                     lowest_res = res
             try:
-                x_mm, y_mm = detector[panel_id].get_beam_centre(beam.get_s0())
+                x_mm, y_mm = detector[panel_id].get_beam_centre(beam.get_unit_s0())
             except RuntimeError:
                 # cope with cases like https://github.com/dials/dials/issues/2478
                 x_mm, y_mm = detector[panel_id].get_bidirectional_ray_intersection(
@@ -583,6 +587,21 @@ class XrayFrame(XFBaseClass):
         else:
             self._score_frame.Destroy()
 
+    def OnLine(self, event):
+        from .line_frame import LineSettingsFrame
+
+        if not self._line_frame:
+            self._line_frame = LineSettingsFrame(
+                self,
+                wx.ID_ANY,
+                "Line tool",
+                style=wx.CAPTION | wx.CLOSE_BOX | wx.RESIZE_BORDER,
+            )
+            self._line_frame.Show()
+            self._line_frame.Raise()
+        else:
+            self._line_frame.Destroy()
+
     def OnPluginWrapper(self, p):
         def OnPlugin(event):
             if not self._plugins_frame[p]:
@@ -653,6 +672,14 @@ class XrayFrame(XFBaseClass):
         else:
             event.SetText("Show score tool")
 
+    def OnUpdateUILine(self, event):
+        # Toggle the menu item text depending on the state of the tool.
+
+        if self._line_frame:
+            event.SetText("Hide line tool")
+        else:
+            event.SetText("Show line tool")
+
     def OnUpdateUIPluginWrapper(self, p):
         def OnUpdateUIPlugin(event):
             # Toggle the menu item text depending on the state of the tool.
