@@ -6,7 +6,7 @@
 #define DIALS_UTIL_SCALED_DOWN_ARRAY_H
 
 #include <ctime>
-#include <boost/random.hpp>
+#include <random>
 #include <dials/array_family/scitbx_shared_and_versa.h>
 
 namespace dials { namespace util {
@@ -19,8 +19,8 @@ namespace dials { namespace util {
                                    const double scale_factor) {
     // create the RNG
 
-    boost::random::mt19937 gen(time(0));
-    boost::random::uniform_real_distribution<double> dist(0, 1);
+    std::mt19937 gen(time(0));
+    std::uniform_real_distribution<double> dist(0, 1);
 
     // create the target array
 
