@@ -6,8 +6,12 @@ from __future__ import annotations
 
 import math
 import os
+import sys
 import time
 
+import OpenGL
+from packaging.version import Version
+
 import gltbx.fonts
 import gltbx.gl as gl
 import gltbx.gl_managed
@@ -18,6 +22,11 @@ import scitbx.math
 from scitbx import matrix
 from scitbx.array_family import flex
 
+# Fix for Python 3.12 and pyopengl <=3.1.7. See https://github.com/silx-kit/silx/pull/3982
+if sys.version_info >= (3, 12) and Version(OpenGL.__version__) <= Version("3.1.7"):
+    # Python3.12 patch: see https://github.com/mcfletch/pyopengl/pull/100
+    OpenGL.FormatHandler.by_name("ctypesparameter").check.append("_ctypes.CArgObject")
+
 try:
     import wx
 except ImportError:
@@ -1069,7 +1078,7 @@ class App(wx.App):
             self.fit_on_screen_id,
             images.fit_img.as_wx_Bitmap(),
             "Fit in window",
-            "Resizes and shifts object to fit into window." " Keyboard shortcut: f",
+            "Resizes and shifts object to fit into window. Keyboard shortcut: f",
         )
 
         self.mark_snap_back_id = wx.NewId()
@@ -1086,8 +1095,7 @@ class App(wx.App):
             self.snap_back_id,
             images.snap_back_img.as_wx_Bitmap(),
             "Snap back orientation",
-            "Rotates object back to the last marked orientation."
-            " Keyboard shortcut: a",
+            "Rotates object back to the last marked orientation. Keyboard shortcut: a",
         )
 
         self.toggle_spin_id = wx.NewId()
