@@ -2,10 +2,8 @@ from __future__ import annotations
 
 import copy
 import logging
-import os
 import pickle
 import random
-from pathlib import Path
 
 import pytest
 
@@ -1095,35 +1093,36 @@ def test_find_overlapping():
             assert is_overlap(b0, b1, i)
 
 
-def test_to_from_msgpack(tmp_path):
-    def gen_shoebox():
-        shoebox = Shoebox(0, (0, 4, 0, 3, 0, 1))
-        shoebox.allocate()
-        for k in range(1):
-            for j in range(3):
-                for i in range(4):
-                    shoebox.data[k, j, i] = i + j + k + 0.1
-                    shoebox.mask[k, j, i] = i % 2
-                    shoebox.background[k, j, i] = i * j + 0.2
-        return shoebox
+def gen_shoebox():
+    shoebox = Shoebox(0, (0, 4, 0, 3, 0, 1))
+    shoebox.allocate()
+    for k in range(1):
+        for j in range(3):
+            for i in range(4):
+                shoebox.data[k, j, i] = i + j + k + 0.1
+                shoebox.mask[k, j, i] = i % 2
+                shoebox.background[k, j, i] = i * j + 0.2
+    return shoebox
 
-    def compare(a, b):
-        assert a.is_consistent()
-        assert b.is_consistent()
-        assert a.panel == b.panel
-        assert a.bbox == b.bbox
-        for aa, bb in zip(a.data, b.data):
-            if abs(aa - bb) > 1e-9:
-                return False
-        for aa, bb in zip(a.background, b.background):
-            if abs(aa - bb) > 1e-9:
-                return False
-        for aa, bb in zip(a.mask, b.mask):
-            if aa != bb:
-                return False
-        return True
 
-    # The columns as lists
+def compare(a, b):
+    assert a.is_consistent()
+    assert b.is_consistent()
+    assert a.panel == b.panel
+    assert a.bbox == b.bbox
+    for aa, bb in zip(a.data, b.data):
+        if abs(aa - bb) > 1e-9:
+            return False
+    for aa, bb in zip(a.background, b.background):
+        if abs(aa - bb) > 1e-9:
+            return False
+    for aa, bb in zip(a.mask, b.mask):
+        if aa != bb:
+            return False
+    return True
+
+
+def table_and_columns():
     c1 = list(range(10))
     c2 = list(range(10))
     c3 = ["a", "b", "c", "d", "e", "f", "g", "i", "j", "k"]
@@ -1134,7 +1133,7 @@ def test_to_from_msgpack(tmp_path):
     c8 = [tuple(i + j for j in range(9)) for i in range(10)]
     c9 = [tuple(i + j for j in range(6)) for i in range(10)]
     c10 = [(i + 1, i + 2, i + 3) for i in range(10)]
-    c11 = [gen_shoebox() for i in range(10)]
+    c11 = [gen_shoebox() for _ in range(10)]
 
     # Create a table with some elements
     table = flex.reflection_table()
@@ -1149,6 +1148,47 @@ def test_to_from_msgpack(tmp_path):
     table["col9"] = flex.int6(c9)
     table["col10"] = flex.miller_index(c10)
     table["col11"] = flex.shoebox(c11)
+    return table, [c1, c2, c3, c4, c5, c6, c7, c8, c9, c10, c11]
+
+
+def test_to_from_h5(tmp_path):
+    # The columns as lists
+    table, columns = table_and_columns()
+    c1, c2, c3, c4, c5, c6, c7, c8, c9, c10, c11 = columns
+    table["id"] = flex.int(table.size(), 0)
+    table.experiment_identifiers()[0] = "test"
+
+    table.as_hdf5(tmp_path / "reflections.h5")
+    new_table = flex.reflection_table.from_hdf5(tmp_path / "reflections.h5")
+    assert new_table.is_consistent()
+    assert new_table.nrows() == 10
+    assert new_table.ncols() == 12  # one more as an id column is needed
+    assert all(tuple(a == b for a, b in zip(new_table["col1"], c1)))
+    assert all(tuple(a == b for a, b in zip(new_table["col2"], c2)))
+    assert all(tuple(a == b for a, b in zip(new_table["col3"], c3)))
+    assert all(tuple(a == b for a, b in zip(new_table["col4"], c4)))
+    assert all(tuple(a == b for a, b in zip(new_table["col5"], c5)))
+    assert all(tuple(a == b for a, b in zip(new_table["col6"], c6)))
+    assert all(tuple(a == b for a, b in zip(new_table["col7"], c7)))
+    assert all(tuple(a == b for a, b in zip(new_table["col8"], c8)))
+    assert all(tuple(a == b for a, b in zip(new_table["col9"], c9)))
+    assert all(tuple(a == b for a, b in zip(new_table["col10"], c10)))
+    assert all(tuple(compare(a, b) for a, b in zip(new_table["col11"], c11)))
+
+    assert all(new_table["id"] == 0)
+    assert dict(new_table.experiment_identifiers()) == {0: "test"}
+
+    # test empty table
+    t = flex.reflection_table([])
+    t.as_hdf5(tmp_path / "empty.h5")
+    empty_table = flex.reflection_table.from_hdf5(tmp_path / "empty.h5")
+    assert list(empty_table.keys()) == []
+    assert not dict(empty_table.experiment_identifiers())
+
+
+def test_to_from_msgpack(tmp_path):
+    table, columns = table_and_columns()
+    c1, c2, c3, c4, c5, c6, c7, c8, c9, c10, c11 = columns
 
     obj = table.as_msgpack()
     new_table = flex.reflection_table.from_msgpack(obj)
@@ -1386,10 +1426,10 @@ def test_as_miller_array():
         _ = table.as_miller_array(experiment, intensity="2")
 
 
-def test_map_centroids_to_reciprocal_space(dials_regression: Path):
-    data_dir = os.path.join(dials_regression, "indexing_test_data", "i04_weak_data")
-    pickle_path = os.path.join(data_dir, "full.pickle")
-    expts_path = os.path.join(data_dir, "experiments_import.json")
+def test_map_centroids_to_reciprocal_space(dials_data):
+    data_dir = dials_data("i04_weak_data")
+    pickle_path = data_dir / "full.pickle"
+    expts_path = data_dir / "experiments_import.json"
 
     refl = flex.reflection_table.from_file(pickle_path)
     expts = load.experiment_list(expts_path, check_format=False)
@@ -1443,10 +1483,10 @@ def test_map_centroids_to_reciprocal_space(dials_regression: Path):
     )
 
 
-def test_calculate_entering_flags(dials_regression: Path):
-    data_dir = os.path.join(dials_regression, "indexing_test_data", "i04_weak_data")
-    pickle_path = os.path.join(data_dir, "full.pickle")
-    experiments_path = os.path.join(data_dir, "experiments_import.json")
+def test_calculate_entering_flags(dials_data):
+    data_dir = dials_data("i04_weak_data")
+    pickle_path = data_dir / "full.pickle"
+    experiments_path = data_dir / "experiments_import.json"
 
     refl = flex.reflection_table.from_pickle(pickle_path)
     experiments = load.experiment_list(experiments_path, check_format=False)
