@@ -2,12 +2,12 @@ from __future__ import annotations
 
 import shutil
 import subprocess
-from pathlib import Path
 
 
-def test(dials_regression: Path, tmp_path):
-    experiments_path = dials_regression / "misc_test_data" / "i04-indexed.json"
-    pickle_path = dials_regression / "misc_test_data" / "i04-indexed.pickle"
+def test(dials_data, tmp_path):
+    data_dir = dials_data("insulin_processed", pathlib=True)
+    experiments_path = data_dir / "indexed.expt"
+    pickle_path = data_dir / "indexed.refl"
 
     assert experiments_path.is_file()
     assert pickle_path.is_file()
