@@ -4,7 +4,6 @@ import os
 import pathlib
 import shutil
 import subprocess
-from pathlib import Path
 
 import pytest
 
@@ -376,13 +375,11 @@ def test_import_beam_centre(dials_data, tmp_path):
     assert beam_centre == pytest.approx((200, 100))
 
 
-def test_fast_slow_beam_centre(dials_regression: pathlib.Path, tmp_path):
+def test_fast_slow_beam_centre(dials_data: pathlib.Path, tmp_path):
     # test fast_slow_beam_centre with a multi-panel CS-PAD image
-    impath = os.path.join(
-        dials_regression,
-        "image_examples",
-        "LCLS_cspad_nexus",
-        "idx-20130301060858401.cbf",
+    impath = (
+        dials_data("image_examples", pathlib=True)
+        / "LCLS_cspad_nexus-idx-20130301060858801.cbf"
     )
     result = subprocess.run(
         [
@@ -432,13 +429,11 @@ def test_fast_slow_beam_centre(dials_regression: pathlib.Path, tmp_path):
     assert offsets == pytest.approx(ref_offsets)
 
 
-def test_distance_multi_panel(dials_regression: pathlib.Path, tmp_path):
+def test_distance_multi_panel(dials_data: pathlib.Path, tmp_path):
     # test setting the distance with a multi-panel CS-PAD image
-    impath = os.path.join(
-        dials_regression,
-        "image_examples",
-        "LCLS_cspad_nexus",
-        "idx-20130301060858401.cbf",
+    impath = str(
+        dials_data("image_examples", pathlib=True)
+        / "LCLS_cspad_nexus-idx-20130301060858801.cbf"
     )
     result = subprocess.run(
         [
@@ -914,14 +909,11 @@ def test_convert_stills_to_sequences(dials_data, tmp_path):
     assert len(experiments3.scans()) == 5  # four for sacla stills, 1 for centroid data
 
 
-def test_convert_stills_to_sequences_nonh5(dials_regression: pathlib.Path, tmp_path):
-    image_path = Path(
-        dials_regression,
-        "image_examples",
-        "LCLS_cspad_nexus",
-        "idx-20130301060858801.cbf",
+def test_convert_stills_to_sequences_nonh5(dials_data: pathlib.Path, tmp_path):
+    image_path = str(
+        dials_data("image_examples", pathlib=True)
+        / "LCLS_cspad_nexus-idx-20130301060858801.cbf"
     )
-    assert image_path.is_file()
     result = subprocess.run(
         [
             shutil.which("dials.import"),
