@@ -3,7 +3,6 @@ from __future__ import annotations
 import json
 import math
 import os
-import pathlib
 import shutil
 import subprocess
 import sys
@@ -417,34 +416,18 @@ def test_basic_integration_with_profile_fitting(dials_data, tmp_path):
     sys.platform == "darwin",
     reason="Not understood apparent platform numeric differences",
 )
-def test_multi_sweep(dials_regression: pathlib.Path, tmp_path):
-    expts = os.path.join(
-        dials_regression, "integration_test_data", "multi_sweep", "experiments.json"
+def test_multi_sweep(dials_data, tmp_path):
+    expts = str(
+        dials_data("centroid_test_data", pathlib=True) / "multi_sweep_indexed.expt"
     )
-
-    experiments = load.experiment_list(expts)
-    for i, expt in enumerate(experiments):
-        expt.identifier = str(100 + i)
-
-    # Patched data file. Original had trusted_range from -1, but now this range
-    # is defined to start from the minimum trusted value. This test should be
-    # updated with new data in dials-data (i.e. not dials_regression).
-    # https://github.com/dials/dials/issues/2200
-    panel = experiments[0].detector[0]
-    max_trusted = panel.get_trusted_range()[1]
-    panel.set_trusted_range((0, max_trusted))
-
-    experiments.as_json(tmp_path / "modified_input.json")
-
-    refls = os.path.join(
-        dials_regression, "integration_test_data", "multi_sweep", "indexed.pickle"
+    refls = str(
+        dials_data("centroid_test_data", pathlib=True) / "multi_sweep_indexed.refl"
     )
-
     result = subprocess.run(
         [
             shutil.which("dials.integrate"),
             "nproc=1",
-            "modified_input.json",
+            expts,
             refls,
             "prediction.padding=0",
         ],
@@ -482,28 +465,18 @@ def test_multi_sweep(dials_regression: pathlib.Path, tmp_path):
     assert flex.abs(I1 - I2) < 1e-6
 
 
-def test_multi_lattice(dials_regression: pathlib.Path, tmp_path):
-    expts = os.path.join(
-        dials_regression, "integration_test_data", "multi_lattice", "experiments.json"
-    )
-
-    experiments = load.experiment_list(expts)
-    for i, expt in enumerate(experiments):
-        expt.identifier = str(100 + i)
-    experiments.as_json(tmp_path / "modified_input.json")
+def test_multi_lattice(dials_data, tmp_path):
+    expt = str(dials_data("trypsin_multi_lattice", pathlib=True) / "refined.expt")
+    refl = str(dials_data("trypsin_multi_lattice", pathlib=True) / "refined.refl")
 
     result = subprocess.run(
         [
             shutil.which("dials.integrate"),
             "nproc=1",
-            "modified_input.json",
-            os.path.join(
-                dials_regression,
-                "integration_test_data",
-                "multi_lattice",
-                "indexed.pickle",
-            ),
+            "d_min=4",
             "prediction.padding=0",
+            expt,
+            refl,
         ],
         cwd=tmp_path,
         capture_output=True,
@@ -512,25 +485,34 @@ def test_multi_lattice(dials_regression: pathlib.Path, tmp_path):
     assert (tmp_path / "integrated.refl").is_file()
     assert (tmp_path / "integrated.expt").is_file()
 
+    # Expected identifiers (should be unchanged from the input)
+    expected_identifiers = {
+        0: "54924b82-9a0e-4b39-840d-0e14b780534b",
+        1: "6c80adf7-3e6f-47a6-abca-916ec3c056a7",
+        2: "7a8dbd6a-11be-429a-ba1f-2d855babaaa5",
+        3: "1b0937cc-e16d-4778-b5b5-4ddc0f772b91",
+        4: "6c745eeb-b835-4c4e-9a31-348ecd4607d8",
+        5: "1584899c-8f81-4d82-b093-44abe1a6f859",
+    }
     experiments = load.experiment_list(tmp_path / "integrated.expt")
-    for i, expt in enumerate(experiments):
-        assert expt.identifier == str(100 + i)
+    assert [e.identifier for e in experiments] == list(expected_identifiers.values())
 
     table = flex.reflection_table.from_file(tmp_path / "integrated.refl")
-    assert len(table) == 4962
-    assert dict(table.experiment_identifiers()) == {0: "100", 1: "101"}
-    # both should only have the imageset_id of zero as they share an imageset
+    assert len(table) == 4020
+    assert dict(table.experiment_identifiers()) == expected_identifiers
+
+    # all 6 experiments should have an imageset_id of zero as they share an imageset
     assert set(table["imageset_id"]) == {0}
 
-    # Check output contains from two lattices
+    # Check output contains from six lattices
     exp_id = list(set(table["id"]))
-    assert len(exp_id) == 2
+    assert len(exp_id) == 6
 
-    # Check both lattices have integrated reflections
+    # Check all lattices have integrated reflections
     mask = table.get_flags(table.flags.integrated_prf)
     table = table.select(mask)
     exp_id = list(set(table["id"]))
-    assert len(exp_id) == 2
+    assert len(exp_id) == 6
 
 
 def test_output_rubbish(dials_data, tmp_path):
@@ -573,30 +555,18 @@ def test_output_rubbish(dials_data, tmp_path):
     assert list(table.experiment_identifiers().values())  # not empty
 
 
-def test_integrate_with_kapton(dials_regression: pathlib.Path, tmp_path):
-    pickle_name = "idx-20161021225550223_indexed.pickle"
-    json_name = "idx-20161021225550223_refined_experiments.json"
-    image_name = "20161021225550223.pickle"
-    pickle_path = os.path.join(
-        dials_regression, "integration_test_data", "stills_PSII", pickle_name
-    )
-    json_path = os.path.join(
-        dials_regression, "integration_test_data", "stills_PSII", json_name
-    )
-    image_path = os.path.join(
-        dials_regression, "integration_test_data", "stills_PSII", image_name
-    )
+def test_integrate_with_kapton(dials_data, tmp_path):
+    data_dir = dials_data("integration_test_data", pathlib=True)
+    refl_path = str(data_dir / "kapton-idx-20161021225550223_indexed.refl")
+    expt_path = str(data_dir / "kapton-idx-20161021225550223_refined.expt")
+    image_path = str(data_dir / "kapton-20161021225550223.pickle")
+    mask_path = str(data_dir / "kapton-mask.pickle")
 
-    assert os.path.exists(pickle_path)
-    assert os.path.exists(json_path)
-    shutil.copy(pickle_path, tmp_path)
+    assert os.path.exists(refl_path)
+    assert os.path.exists(expt_path)
+    shutil.copy(refl_path, tmp_path)
     shutil.copy(image_path, tmp_path)
 
-    with open(json_path) as r:
-        (tmp_path / json_name).write_text(
-            r.read() % os.fspath(tmp_path).replace("\\", "\\\\")
-        )
-
     templ_phil = """
       output {
         experiments = 'idx-20161021225550223_integrated_experiments_%s.expt'
@@ -627,17 +597,13 @@ def test_integrate_with_kapton(dials_regression: pathlib.Path, tmp_path):
     without_kapton_phil = templ_phil % (
         "nokapton",
         "nokapton",
-        os.path.join(
-            dials_regression, "integration_test_data", "stills_PSII", "mask.pickle"
-        ).replace("\\", "\\\\"),
+        mask_path,
         "False",
     )
     with_kapton_phil = templ_phil % (
         "kapton",
         "kapton",
-        os.path.join(
-            dials_regression, "integration_test_data", "stills_PSII", "mask.pickle"
-        ).replace("\\", "\\\\"),
+        mask_path,
         "True",
     )
 
@@ -648,7 +614,7 @@ def test_integrate_with_kapton(dials_regression: pathlib.Path, tmp_path):
     # Call dials.integrate with and without kapton correction
     for phil in "integrate_without_kapton.phil", "integrate_with_kapton.phil":
         result = subprocess.run(
-            ["dials.integrate", "nproc=1", pickle_name, json_name, phil],
+            [shutil.which("dials.integrate"), "nproc=1", refl_path, expt_path, phil],
             cwd=tmp_path,
             capture_output=True,
         )
