@@ -3,7 +3,6 @@ from __future__ import annotations
 import shutil
 import subprocess
 from os import path
-from pathlib import Path
 
 import pytest
 
@@ -12,10 +11,9 @@ from dxtbx.serialize import load
 from dials.command_line.modify_geometry import phil_scope, update
 
 
-def test_run(dials_regression: Path, tmp_path):
-    orig_expt_json = path.join(
-        dials_regression, "experiment_test_data", "kappa_experiments.json"
-    )
+def test_run(dials_data, tmp_path):
+    orig_expt_json = dials_data("experiment_test_data") / "kappa_experiments.json"
+
     assert path.exists(orig_expt_json)
 
     orig_expt = load.experiment_list(orig_expt_json, check_format=False)
