@@ -3,15 +3,14 @@ from __future__ import annotations
 import os
 import shutil
 import subprocess
-from pathlib import Path
 
 from dxtbx.serialize import load
 
 from dials.command_line.show import model_connectivity, run
 
 
-def test_dials_show(dials_regression: Path):
-    path = os.path.join(dials_regression, "experiment_test_data", "experiment_1.json")
+def test_dials_show(dials_data):
+    path = str(dials_data("experiment_test_data", pathlib=True) / "experiment_1.json")
     result = subprocess.run(
         [shutil.which("dials.show"), path],
         env={"DIALS_NOBANNER": "1", **os.environ},
@@ -70,15 +69,15 @@ Goniometer:
 Crystal:
     Unit cell: 42.272, 42.272, 39.670, 90.000, 89.999, 90.000
     Space group: P 4 2 2
-    U matrix:  {{ 0.8336, -0.5360, -0.1335},
-                {-0.1798, -0.0348, -0.9831},
-                { 0.5223,  0.8435, -0.1254}}
-    B matrix:  {{ 0.0237,  0.0000,  0.0000},
-                {-0.0000,  0.0237,  0.0000},
-                {-0.0000,  0.0000,  0.0252}}
-    A = UB:    {{ 0.0197, -0.0127, -0.0034},
-                {-0.0043, -0.0008, -0.0248},
-                { 0.0124,  0.0200, -0.0032}}
+    U matrix:  {{ 0.833603, -0.535987, -0.133506},
+                {-0.179804, -0.034770, -0.983088},
+                { 0.522280,  0.843510, -0.125357}}
+    B matrix:  {{ 0.023656,  0.000000,  0.000000},
+                {-0.000000,  0.023656,  0.000000},
+                {-0.000000,  0.000000,  0.025208}}
+    A = UB:    {{ 0.019720, -0.012679, -0.003365},
+                {-0.004253, -0.000823, -0.024781},
+                { 0.012355,  0.019954, -0.003160}}
     Mosaicity:  0.157000
 """.strip()
     )
