@@ -1,15 +1,14 @@
 from __future__ import annotations
 
-import os
 import pickle
 from pathlib import Path
 
 
-def test_spot_counts_per_image_plot(dials_regression: Path):
+def test_spot_counts_per_image_plot(dials_data: Path):
     from dials.util import ascii_art
 
-    data_dir = os.path.join(dials_regression, "indexing_test_data", "i04_weak_data")
-    pickle_path = os.path.join(data_dir, "full.pickle")
+    data_dir = dials_data("i04_weak_data")
+    pickle_path = data_dir / "full.pickle"
 
     with open(pickle_path, "rb") as fh:
         refl = pickle.load(fh, encoding="bytes")
