@@ -246,7 +246,6 @@ def test_invalid_yml(tmp_path):
     reason="Failures due to translated paths; see https://github.com/cctbx/dxtbx/issues/613",
 )
 def test_real_h5_example(tmp_path, dials_data):
-
     """This test tests a few use cases on processed data derived from h5 format."""
     fpath1 = (
         "/dls/mx/data/nt30330/nt30330-15/VMXi-AB1698/well_42/images/image_58766.nxs"
@@ -395,7 +394,6 @@ grouping:
     reason="Failures due to translated paths; see https://github.com/cctbx/dxtbx/issues/613",
 )
 def test_real_cbf_example(tmp_path, dials_data):
-
     """This test tests a few use cases on real cbf data, using the template
     metadata definition.
 
@@ -455,15 +453,15 @@ grouping:
     assert len(filelist_1) == 1
     expts1 = load.experiment_list(filelist_1[0].expt)
     assert len(expts1) == 2
-    assert expts1[0].imageset.get_path(0).split("_")[-1] == "17002.cbf"
-    assert expts1[1].imageset.get_path(0).split("_")[-1] == "17004.cbf"
+    assert expts1[0].scan.get_image_range() == (17002, 17002)
+    assert expts1[1].scan.get_image_range() == (17004, 17004)
     filelist_2 = fd["group_2"]
     assert len(filelist_2) == 1
     expts2 = load.experiment_list(filelist_2[0].expt)
     assert len(expts2) == 3
-    assert expts2[0].imageset.get_path(0).split("_")[-1] == "17001.cbf"
-    assert expts2[1].imageset.get_path(0).split("_")[-1] == "17001.cbf"
-    assert expts2[2].imageset.get_path(0).split("_")[-1] == "17003.cbf"
+    assert expts2[0].scan.get_image_range() == (17001, 17001)
+    assert expts2[1].scan.get_image_range() == (17001, 17001)
+    assert expts2[2].scan.get_image_range() == (17003, 17003)
 
     # Now test on imported data. Here, we have one imagesequence, expect
     # images 17000-17004, to be split into alternating groups.
@@ -511,19 +509,19 @@ grouping:
     assert len(filelist_1) == 1
     expts1 = load.experiment_list(filelist_1[0].expt)
     assert len(expts1) == 2
-    assert expts1[0].imageset.get_path(0).split("_")[-1] == "17001.cbf"
-    assert expts1[1].imageset.get_path(0).split("_")[-1] == "17001.cbf"
+    assert expts1[0].scan.get_image_range()[0] == 17001
+    assert expts1[1].scan.get_image_range()[0] == 17001
     filelist_2 = fd["group_2"]
     assert len(filelist_2) == 1
     expts2 = load.experiment_list(filelist_2[0].expt)
     assert len(expts2) == 2
-    assert expts2[0].imageset.get_path(0).split("_")[-1] == "17002.cbf"
-    assert expts2[1].imageset.get_path(0).split("_")[-1] == "17003.cbf"
+    assert expts2[0].scan.get_image_range()[0] == 17002
+    assert expts2[1].scan.get_image_range()[0] == 17003
     filelist_3 = fd["group_3"]
     assert len(filelist_3) == 1
     expts3 = load.experiment_list(filelist_3[0].expt)
     assert len(expts3) == 1
-    assert expts3[0].imageset.get_path(0).split("_")[-1] == "17004.cbf"
+    assert expts3[0].scan.get_image_range()[0] == 17004
 
     # Check writing the group ids to the file. Don't overwrite dials_data files though
     fps_copy = [
